@@ -11,11 +11,11 @@ import warnings
 from ._utils import (
     _drop_keys_with_none_values,
     _execute_shell_command,
+    _filter_by_type,
     _generate_command_by_dict,
-    _get_dict_from_stdout,
-    _print_std,
-    _update_dict_by_dict,
+    _generate_dict_interfaces,
     _generate_dict_list_targets,
+    _get_dict_from_stdout,
 )
 
 # Loading constants Constants.py
@@ -57,7 +57,7 @@ class Controller:
     }
 
     _pipewire_list_targets = {  # "--list-targets": None,
-        "list_playblack": None,
+        "list_playback": None,
         "list_record": None,
     }
 
@@ -420,7 +420,7 @@ class Controller:
         if mode == "playback":
             mycommand = ["pw-cat", "--playback", "--list-targets"]
             stdout, _ = _execute_shell_command(command=mycommand, timeout=-1, verbose=verbose)
-            self._pipewire_list_targets["list_playblack"] = _generate_dict_list_targets(
+            self._pipewire_list_targets["list_playback"] = _generate_dict_list_targets(
                 longstring=stdout.decode(), verbose=verbose
             )
         elif mode == "record":
@@ -450,7 +450,7 @@ class Controller:
         ```python
         >>> Controller().get_list_targets()
         {
-        "list_playblack": {
+        "list_playback": {
             "86": {
             "description": "Starship/Matisse HD Audio Controller Pro",
             "prior": "936"
@@ -483,11 +483,54 @@ class Controller:
         }
         ```
         """
-
         if verbose:
             print(self._pipewire_list_targets)
         return self._pipewire_list_targets
 
+    def get_list_interfaces(
+        self,
+        filtered_by_type: str = True,
+        type_interfaces: str = "Client",
+        # Debug
+        verbose: bool = False,
+    ):
+        """Returns a list of applications currently using pipewire on Client.
+        An example of pw-cli usage is the code below:
+
+        ```bash
+        #!/bin/bash
+        pw-cli ls Client
+        ```
+        Args:
+            filtered_by_type : If False, returns all. If not, returns a fitered dict
+            type_interfaces : Set type of Interface ["Client","Link","Node","Factory","Module","Metadata","Endpoint","Session","Endpoint Stream","EndpointLink","Port"]
+
+        Returns:
+            - dict_interfaces_filtered: dictionary with list of interfaces matching conditions
+
+        Examples:
+        ```python
+        >>> Controller().get_list_interfaces()
+
+        ```
+        """
+        mycommand = ["pw-cli", "info", "all"]
+
+        # if verbose:
+        #     print(f"[mycommand]{mycommand}")
+
+        stdout, _ = _execute_shell_command(command=mycommand, timeout=-1, verbose=verbose)
+        dict_interfaces = _generate_dict_interfaces(longstring=stdout.decode(), verbose=verbose)
+
+        if filtered_by_type:
+            dict_interfaces_filtered = _filter_by_type(
+                dict_interfaces=dict_interfaces, type_interfaces=type_interfaces
+            )
+        else:
+            dict_interfaces_filtered = dict_interfaces
+
+        return dict_interfaces_filtered
+
     def playback(
         self,
         audio_filename: str = "myplayback.wav",
